summaryrefslogtreecommitdiffstats
path: root/konquest/mainwin.cc
diff options
context:
space:
mode:
Diffstat (limited to 'konquest/mainwin.cc')
-rw-r--r--konquest/mainwin.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/konquest/mainwin.cc b/konquest/mainwin.cc
index a5306172..fdc44e13 100644
--- a/konquest/mainwin.cc
+++ b/konquest/mainwin.cc
@@ -26,7 +26,7 @@ MainWindow::MainWindow()
setCaption( i18n("Galactic Conquest") );
setupGameBoard();
- setupKAction();
+ setupTDEAction();
setupGUI();
}
@@ -35,22 +35,22 @@ MainWindow::~MainWindow()
}
void
-MainWindow::setupKAction()
+MainWindow::setupTDEAction()
{
KStdGameAction::gameNew( TQT_TQOBJECT(gameBoard), TQT_SLOT( startNewGame() ), actionCollection() );
KStdGameAction::quit( TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection() );
endAction = KStdGameAction::end( TQT_TQOBJECT(gameBoard), TQT_SLOT( shutdownGame() ), actionCollection() );
endAction->setEnabled(false);
- //AB: there is no icon for disabled - KToolBar::insertButton shows the
- //different state - KAction not :-(
- measureAction = new KAction( i18n("&Measure Distance"), "ruler", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( measureDistance() ), actionCollection(), "game_measure" );
+ //AB: there is no icon for disabled - TDEToolBar::insertButton shows the
+ //different state - TDEAction not :-(
+ measureAction = new TDEAction( i18n("&Measure Distance"), "ruler", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( measureDistance() ), actionCollection(), "game_measure" );
measureAction->setEnabled(false);
- standingAction = new KAction( i18n("&Show Standings"), "help", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( showScores() ), actionCollection(), "game_scores" );
+ standingAction = new TDEAction( i18n("&Show Standings"), "help", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( showScores() ), actionCollection(), "game_scores" );
standingAction->setEnabled(false);
- fleetAction = new KAction( i18n("&Fleet Overview"), "launch", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( showFleets() ), actionCollection(), "game_fleets" );
+ fleetAction = new TDEAction( i18n("&Fleet Overview"), "launch", 0, TQT_TQOBJECT(gameBoard), TQT_SLOT( showFleets() ), actionCollection(), "game_fleets" );
fleetAction->setEnabled(false);
- toolBar()->setBarPos( KToolBar::Left );
+ toolBar()->setBarPos( TDEToolBar::Left );
toolBar()->setMovingEnabled( false );
}